The main purpose of the package feisr is the estimation of fixed
effects individual slopes models and respective test statistics.
The fixed effects individual slopes (FEIS) estimator is a more general
version of the well-known fixed effects estimator (FE), which allows to
control for heterogeneous slopes in addition to time-constant heterogeneity
Bruderl.2015.387,Ruttenauer.2020,Wooldridge.2010.384feisr.
This is done by running an lm() model on pre-transformed data, where
we (1) estimate the individual-specific predicted values for the dependent
variable and each covariate based on an individual intercept and the additional
slope variables, (2) detrend the original data by these individual-specific
predicted values, and (3) run an OLS model on the residual data. The package
also provides two specification test for heterogeneous slopes
@more details and examples can be found in @Ruttenauer.2020feisr.
Tobias Ruettenauer
Volker Ludwig
The main functions of the feisr package are:
- feis(): fixed effects individual slopes estimator by
applying lm to detrended data.
- feistest(): regression-based Hausman test for fixed effects
individual slope models.
- bsfeistest(): bootstrapped Hausman test for fixed effects
individual slope models.
The functions included in the R package feisr are also available in the
xtfeis ado (https://ideas.repec.org/c/boc/bocode/s458045.html)
for Stata. The plm-package provides functions
for estimation of related models, like the mean group (MG) or common
correlated effects mean groups (CCEMG) estimator via pmg or
models with variable coefficients via pvcm.
_PACKAGE
plm, pvcm, pmg